@@ -1,7 +1,7 @@
 """This is my first moduele
 It's great"""
 
-def print_lol(the_list, level):
+def print_lol(the_list, level=0):
     """this def is recursion"""
     for i in the_list:
         if isinstance(i, list):
